@@ -332,6 +332,8 @@ def process_bulkstatus(df):
         df.loc[(df['BulkStatus'] == 12), 'is_NN'] = 1
         df.drop(labels=['BulkStatus'],axis=1,inplace=True)
         logger.info('Deleted BulkStatus column')
+        logger.info(df['is_OOO'].value_counts())
+        logger.info(df['is_NN'].value_counts())
     else:
         logger.info('Column not present')
     return df
@@ -392,6 +394,7 @@ def fill_variables(df):
     for key in variables_dict.keys():        
         if key in df:
             logger.info(f'Filling variable {key} nulls with {variables_dict[key]}')
+            logger.info(df[key].isna().sum())
             df[key] = df[key].fillna(variables_dict[key])
         else:
             logger.info(f'{key} not available to fill')
